# Input 1: Parameters
β = 0.95
γ = 2.5
zˣ = 0.0179
ϕ₁ = -0.139
xˣ = 0.0012
ϕ₂ = 0.8552
w = 0.74e-5
r = 1e-8

# Input 2: Define control and states (y,x)  
(lq,z,x) = Sym("lq z x")
vars = (lq,z,x)
cntrl = [1]
state = [2;3]

# Input 3: Model's definition
q = exp(lq)
F = [β*exp((1-γ)*z)*(1+q);z;x]
G = [q;(1-ϕ₁)*zˣ+ϕ₁*z;(1-ϕ₂)*xˣ+ϕ₂*x]

# Input 4: Deterministic steady state (DSS) 
xss = xˣ
zss = zˣ
qss = β*exp((1-γ)*zss)/(1-β*exp((1-γ)*zss))
lqss = log(qss)

nsss = (lqss,zss,xss)

# Input 5: Variance-covariance matrix  
Σ = [(1-ϕ₂)*xˣ+ϕ₂*x 0; 0 w^2]

# Build model's solution approximation and compute risky steady state
rss,policy = RiskySS(F,G,vars,nsss,cntrl,state,Σ)

# Model simulation (plot IRF and policy functions)
T = 20
tau = 5
var_shocked = 2
shock = sqrt(xˣ)
imp = (var_shocked,tau,shock)

variables = ImpResp(T,imp,policy,cntrl,state)

display(plot(1:T,variables[:,1:2],title = "Model_2",label = ["lq" "z"],LineWidth = 3,xlabel = "time",ylabel="Responses"))

StateGrid = [-2*sqrt(xˣ) 2*sqrt(xˣ); -4*w 4*w]
C = PolicyPlot(StateGrid,10,policy)
C = exp.(C .+ rss[1])

include("AnalyticModel_2.jl")
zz = Vector(-2*sqrt(xˣ):4*sqrt(xˣ)/9:2*sqrt(xˣ))
CC1 = zeros(10)
for i = 1:10
    zx = [zz[i]+zss;xss]
    CC1[i] = fanalyticModel_2(zx)
end

xx = Vector(-4*w:8*w/9:4*w)
CC2 = zeros(10)
for i = 1:10
    zx = [zss;xx[i]+xss]
    CC2[i] = fanalyticModel_2(zx)
end


c1 = zeros(10,1)
c2 = zeros(10,1)
c1[:,1] = C[1,:,:]
c2[:,1] = C[2,:,:]

zz = zz .+ zss
xx = xx .+ xss
display(plot(zz,[c1 CC1],title = "Model_2",label = ["Risk Sensitive" "true"],LineWidth = 3,xlabel = "zₜ-zₛₛ",ylabel = "lqₜ-lqₛₛ"))
display(plot(xx,[c2 CC2],title = "Model_2",label = ["Risk Sensitive" "true"],LineWidth = 3,xlabel = "xₜ-xₛₛ",ylabel = "lqₜ-lqₛₛ"))