# Input 1: Parameters
β = 0.95
γ = 2.5
zˣ = 0.0179
ϕ₁ = -0.139
xˣ = 0.0012
ϕ₂ = 0.8552
ϕ₃ = 0.04/10
w = 0.74e-5
r = 1e-8

# Input 2: Define control and states (y,x)
(lq,z,x) = Sym("lq z x")
vars = (lq,z,x)
cntrl = [1]
state = [2;3]

# Input 3: Model's definition
q = exp(lq)
F = [β*exp((1-γ)*z)*(1+q);z;x]
G = [q;(1-ϕ₁)*zˣ+ϕ₁*z;(1-ϕ₂)*xˣ+ϕ₂*x+ϕ₃*x]

# Input 4: Deterministic steady state (DSS) 
xss = xˣ
zss = zˣ
qss = β*exp((1-γ)*zss)/(1-β*exp((1-γ)*zss))
lqss = log(qss)

nsss = (lqss,zss,xss)

# Input 5: Variance-covariance matrix  
Σ = [x 0; 0 ϕ₃^2*x^2*2]

# Build model's solution approximation and compute risky steady state
rss,policy = RiskySS(F,G,vars,nsss,cntrl,state,Σ)

# Model simulation (plot IRF and policy functions)
T = 20
tau = 5
var_shocked = [2;3]
shock = [sqrt(xˣ);ϕ₃*xˣ]
imp = (var_shocked,tau,shock)

variables = ImpResp(T,imp,policy,cntrl,state)

display(plot(1:T,variables[:,1:2],title = "Model_3",label = ["lq" "z"],LineWidth = 3,xlabel = "time",ylabel="Responses"))

StateGrid = [-2*sqrt(xˣ) 2*sqrt(xˣ);-2*ϕ₃*xˣ*sqrt(2) 2*ϕ₃*xˣ*sqrt(2)]
C = PolicyPlot(StateGrid,10,policy)
C = exp.(C .+ rss[1])

zz = Vector(-2*sqrt(xˣ):4*sqrt(xˣ)/9:2*sqrt(xˣ))
xx = Vector(-2*ϕ₃*xˣ*sqrt(2):4*ϕ₃*xˣ*sqrt(2)/9:2*ϕ₃*xˣ*sqrt(2))

zz = zz .+ zss
xx = xx .+ xss
display(plot(zz,c1,title = "Model_3",label = "Risk Sensitive",LineWidth = 3,xlabel = "zₜ-zₛₛ",ylabel = "lqₜ-lqₛₛ"))
display(plot(xx,c2,title = "Model_3",label = "Risk Sensitive",LineWidth = 3,xlabel = "xₜ-xₛₛ",ylabel = "lqₜ-lqₛₛ"))
