function [Theta,theta,Omega,omega] = BKstaticEq(F,G,g,cntrl,state,r)
  
  nc = length(cntrl);
  ns = length(state);
  n = nc+ns;
  
  Eqs = 1:n;
  staEq = sum(abs(F),2)<1e-8;
  nseq = sum(staEq);
  dynEq = Eqs(staEq == 0);
  
  if nseq == 0
    A = F\G;
    b = F\g;
    [Theta,theta,Omega,omega] = BlanKahn(A,b,cntrl,state,r);
  
  elseif nseq == nc
    Theta = -G(staEq,cntrl)\G(staEq,state);
    theta = -G(staEq,cntrl)\g(staEq);
    
    nF = F(dynEq,state)+F(dynEq,cntrl)*Theta;
    nG = G(dynEq,state)+G(dynEq,cntrl)*Theta;
    ng = g(dynEq)+(G(dynEq,cntrl)-F(dynEq,cntrl))*theta;
    
    Omega = nF\nG;
    omega = nF\ng;
    
    if max(abs(eig(Omega))) >= 1+r
      error('The system has no solution');
    end
  
  else
    [R,sta]=rref(G(staEq,cntrl));
    
    stavars = cntrl(sta);
    dynvars = 1:n;
    dynvars(stavars) = [];
    
    Psi = -G(staEq,stavars)\G(staEq,dynvars);
    psi = -G(staEq,stavars)\g(staEq);
    
    nF = F(dynEq,dynvars)+F(dynEq,stavars)*Psi;
    nG = G(dynEq,dynvars)+G(dynEq,stavars)*Psi;
    ng = g(dynEq)+(G(dynEq,stavars)-F(dynEq,stavars))*psi;
    
    A = nF\nG;
    b = nF\ng;
    
    cs = zeros(1,n);
    cs(cntrl) = 1;
    cs(state) = 2;
    cs(stavars) = [];
    nvars = 1:n-nseq;
    ncntrl = nvars(cs == 1);
    nstate = nvars(cs == 2); 
    
    [Theta1,theta1,Omega,omega] = BlanKahn(A,b,ncntrl,nstate,r);
   
    H = zeros(n-nseq,ns);
    H(ncntrl,:) = Theta1;
    H(nstate,:) = eye(ns);
    
    cd = zeros(1,n);
    cd(cntrl) = 1;
    cd(stavars) = 2;
    cd(state) = [];
    cnvars = 1:nc;
    cnsta = cnvars(cd == 2);
    cndyn = cnvars(cd == 1);
    
    Theta = zeros(nc,ns);
    theta = zeros(nc,1);    
    Theta(cndyn,:) = Theta1;
    Theta(cnsta,:) = Psi*H;
    theta(cndyn) = theta1;
    theta(cnsta) = Psi(:,ncntrl)*theta1+psi;
  end  
end
