function [Theta2,theta2,Omega2,omega2] = ParrSol(F1,F2,G1,g1,Sig,cntrl,state)
  %Benignos solves second order Euler systems with volatility
  %with the Lombardo - Sutherland (2007) Method.
  %The system has to be express as:
  % F1*Y(t+1)+1/2*F2*vec(Y(t+1)*Y(t+1)') = G1*Y(t)+G2*vec(Y(t)Y(t)')
  %Author: Gustavo P. Solorzano
  %ADVANCED-ECON.COM  
  
  nc = length(cntrl);
  ns = length(state);
  n = nc+ns;
  [Theta,theta,Omega,omega] = BKstaticEq(F1,G1,g1,cntrl,state,0);
  
  H = zeros(n,ns);
  o = ones(ns,n);
  H(state,:) = eye(ns);
  H(cntrl,:) = Theta;
  H2 = Gamma2(H).*Gamma2(o)';
  
 
  F = [F1];
  G = [G1];
  g = [g1-1/2*F2*H2*vec_var(Sig)];
    
  [Theta2,theta2,Omega2,omega2] = BKstaticEq(F,G,g,cntrl,state,0);
end
