function [Theta3,theta3,Omega3,omega3] = ParrSol3(F1,F2,F3,G1,g1,Sig,Xi,cntrl,state)
  %LombSuth solves third order Euler systems
  %with the Lombardo - Sutherland (2007) Method.
  %The system has to be express as:
  % F1*Y(t+1)+1/2*F2*vec(Y(t+1)*Y(t+1)') = G1*Y(t)+G2*vec(Y(t)Y(t)')
  %Author: Gustavo P. Solorzano
  %ADVANCED-ECON.COM  
  
  nc = length(cntrl);
  ns = length(state);
  n = nc+ns;
  ns3 = ns*(ns+1)*(ns+2)/6;
  
  [Theta,theta,Omega,omega] = BKstaticEq(F1,G1,g1,cntrl,state,0);
  

  H = zeros(n,ns);
  o = ones(ns,n);
  H(state,:) = eye(ns);
  H(cntrl,:) = Theta;
  H2 = Gamma2(H).*Gamma2(o)';
  H3 = Gamma3(H).*Gamma3(o)';
 
       
  F = [F1];
  G = [G1];
  g = [g1-1/2*F2*H2*vec_var(Sig)-1/6*F3*H3*vec_m3(Xi)];  
    
  [Theta3,theta3,Omega3,omega3] = BKstaticEq(F,G,g,cntrl,state,0);
end
