function [Theta,theta,Omega,omega] = ParrSolv(F1,F2,G1,g1,Sig,DSig,cntrl,state)
  %Benignos solves second order Euler systems with volatility
  %with the Lombardo - Sutherland (2007) Method.
  %The system has to be express as:
  % F1*Y(t+1)+1/2*F2*vec(Y(t+1)*Y(t+1)') = G1*Y(t)+G2*vec(Y(t)Y(t)')
  %Author: Gustavo P. Solorzano
  %ADVANCED-ECON.COM  
  
  nc = length(cntrl);
  ns = length(state);
  n = nc+ns;
  [Theta,theta,Omega,omega] = BKstaticEq(F1,G1,g1,cntrl,state,0);
  
  
  H = zeros(n,ns);
  o = ones(ns,n);
  H(state,:) = eye(ns);
  for iter = 1:100
    H(cntrl,:) = Theta;
    H2 = Gamma2(H).*Gamma2(o)';
  
    for i = 1:n
      vDSig(:,i) = vec_var(DSig(:,ns*(i-1)+1:ns*i));
    end
    
    if F2 == 0
        F = F1;
        G = G1;
        g = g1;
    else
        F = [F1];
        G = [G1-1/2*F2*H2*vDSig];
        g = [g1-1/2*F2*H2*vec_var(Sig)];
    end
    
    [nTheta,ntheta,Omega,omega] = BKstaticEq(F,G,g,cntrl,state,0);
    if max(abs([nTheta ntheta]-[Theta theta]))<1e-6
      break
    end
    Theta = nTheta;
    theta = ntheta;
  end
end